<?php
/* This file is part of the wp-forecast plugin for wordpress */

/*  Copyright 2006  Hans Matzen  (email : webmaster at tuxlog.de)

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

// uri for location search
$LOC_URI="http://forecastfox.accuweather.com/adcbin/forecastfox/locate_city.asp?location=";

// location array and counter init
$loc=array();
$i=0;

// generic functions
require_once("functions.php");

//
// add menuitem to options menu
//
function wp_forecast_admin() 
{
    if (function_exists('add_options_page')) {
	add_options_page('WP-Forecast', 'WP-Forecast', 6, 
			 basename(__FILE__), 'admin_form');
    }
}

//
// delete cookie if parameters are changed, to make sure
// current data will be available with next call
//
function wp_forecast_admin_init() 
{
    if ( ($_SERVER['QUERY_STRING']=="page=wp-forecast-admin.php") && (isset($_POST['info_update']) ))
    {
        // delete cookie for old location
	setcookie("wp_forecast_cache",'', time() - 3600,"/wordpress/");
    }
}

//
// get the locationlist and return it in one long string
//
function get_loclist($uri,$loc)
{
    $url=$uri . urlencode($loc);
    $xml = fetchURL($url);
    
    return $xml;
}

//
// parse xml and extract locations as an array
// for later us in the admin form
//
function get_locations($xml)
{
    // start_element() - wird vom XML-Parser bei öffnenden Tags aufgerufen
    function s_element( $parser, $name, $attribute )
	{
	    // Umwandlungstabelle in den lokalen Scope holen
	    global $loc,$i;
	    if ($name == "LOCATION") {
		$loc[$i]=array();
		$loc[$i]['city'] = $attribute['CITY'];
		$loc[$i]['state'] = $attribute['STATE'];
		$loc[$i]['location'] = $attribute['LOCATION'];
		$i++;
	    }
	}
	    
    // end_element() - dummy function
    function e_element( $parser, $name ){}
    
    // Instanz des XML-Parsers erzeugen
    $parser = xml_parser_create();
    
    // Parameter des XML-Parsers setzen 
    xml_parser_set_option( $parser, XML_OPTION_CASE_FOLDING, true ); 
    
    // Handler für Elemente ( öffnende / schließende Tags ) setzen 
    xml_set_element_handler( $parser, "s_element", "e_element" ); 
    
    // Versuche zu parsen
    if( !xml_parse( $parser, $xml,true ) )
    {
	// Fehler -> Ausführung abbrechen
	die(  "XML Fehler: " . 
	      xml_error_string( xml_get_error_code( $parser ) ) . 
	      " in Zeile " .
	      xml_get_current_line_number( $parser )
	    );
    }
    
    // Vom XML-Parser belegten Speicher freigeben
    xml_parser_free( $parser );

    // und zurueckgeben
    return $loc;
}
    
//
// form to modify wp-forecast setup
// options in wp_option: wp-forecast-location, wp-forecast-refresh
//                       wp-forecast-metric,   wp-forecast-language
//                       wp-forecast-daytime   wp-forecast-nighttime
//
// the form also has a search function to search the wright location
//
function admin_form() {
    global $LOC_URI,$loc;

    // get options
    $location=get_option("wp-forecast-location");
    $refresh=get_option("wp-forecast-refresh"); 
    $metric=get_option("wp-forecast-metric"); 
    $language=get_option("wp-forecast-language");
    $daytime=get_option("wp-forecast-daytime");
    $nighttime=get_option("wp-forecast-nighttime");

    
    // if this is a POST call, save new values
    if (isset($_POST['info_update'])) {
	$upflag=false;
	
	if ($location != $_POST["location"]) {
	    $location =  $_POST["location"];
	    update_option("wp-forecast-location", $location);
	    $upflag=true;
	}
	
	if ($refresh != $_POST["refresh"]) {
	    $refresh =  $_POST["refresh"];
	    update_option("wp-forecast-refresh", $refresh);
	    $upflag=true;
	}
	
	if ($metric != $_POST["metric"]) {
	    $metric =  $_POST["metric"];
	    if ($metric=="") $metric="0";
	    update_option("wp-forecast-metric", $metric);
	    $upflag=true;
	}
	
	if ($language != $_POST["language"]) {
	    $language =  $_POST["language"];
	    update_option("wp-forecast-language", $language);
	    $upflag=true;
	}
	
	// set checkbox value to zero if not set
	// for forecast options
	if ($_POST["day1"]=="")
	  $_POST["day1"]="0";
	if ($_POST["day2"]=="")
	  $_POST["day2"]="0";
	if ($_POST["day3"]=="")
	  $_POST["day3"]="0";	
	if ($_POST["day4"]=="")
	  $_POST["day4"]="0";	
	if ($_POST["day5"]=="")
	  $_POST["day5"]="0";	
	if ($_POST["day6"]=="")
	  $_POST["day6"]="0";	
	if ($_POST["day7"]=="")
	  $_POST["day7"]="0";	
	if ($_POST["day8"]=="")
	  $_POST["day8"]="0";	
	if ($_POST["day9"]=="")
	  $_POST["day9"]="0";
	if ($_POST["night1"]=="")
	  $_POST["night1"]="0";
	if ($_POST["night2"]=="")
	  $_POST["night2"]="0";
	if ($_POST["night3"]=="")
	  $_POST["night3"]="0";	
	if ($_POST["night4"]=="")
	  $_POST["night4"]="0";	
	if ($_POST["night5"]=="")
	  $_POST["night5"]="0";	
	if ($_POST["night6"]=="")
	  $_POST["night6"]="0";	
	if ($_POST["night7"]=="")
	  $_POST["night7"]="0";	
	if ($_POST["night8"]=="")
	  $_POST["night8"]="0";	
	if ($_POST["night9"]=="")
	  $_POST["night9"]="0";

	// build config string for forecast and update if necessary
	$newdaytime=$_POST["day1"].$_POST["day2"].$_POST["day3"].$_POST["day4"].$_POST["day5"].$_POST["day6"].$_POST["day7"].$_POST["day8"].$_POST["day9"];
	
	if ($daytime != $newdaytime) {
	  $daytime =  $newdaytime;
	  update_option("wp-forecast-daytime", $newdaytime);
	  $upflag=true;
	}
	// build config string for forecast and update if necessary
	$newnighttime=$_POST["night1"].$_POST["night2"].$_POST["night3"].$_POST["night4"].$_POST["night5"].$_POST["night6"].$_POST["night7"].$_POST["night8"].$_POST["night9"];
	
	if ($nighttime != $newnighttime) {
	  $nighttime =  $newnighttime;
	  update_option("wp-forecast-nighttime", $newnighttime);
	  $upflag=true;
	}	
 
    ?><div class="updated"><p><strong><?php 
	   if ($upflag) 
	       _e('Settings successfully updated','Localization name');
	   else
	       _e('You have to change a field to update settings.');

    ?></strong></p></div><?php
	} 

    // if this is a POST call, search locations
    if (isset($_POST['search_loc'])) {
	$xml=get_loclist($LOC_URI,$_POST["searchloc"]);
	$xml=utf8_encode($xml);
	get_locations($xml);
    }

    // if this is a POST call, set location
    if (isset($_POST['set_loc'])) {
	$location=$_POST["newloc"];
    }
    
?>

	 <div class=wrap>
	 <form method="post">
	 <h2>WP-Forecast Setup</h2>
	 <fieldset name="set1">
	 <legend><?php _e('Parameters', 'Localization name') ?></legend><p>
	 <b>Location:</b>
	 <input name="location" type="text" size="30" maxlength="80" value="<?php echo $location ?>">
	 <?php if (isset($_POST['set_loc'])) { ?>
	       <b>Press Update options to save new location.</b>
         <?php } ?>
         <br><p>
	 <b>Refresh cache after</b>
         <input name="refresh" type="text" size="10" maxlength="6" value="<?php echo $refresh ?>">
         <b>secs.</b><br><p>
	 <input type="checkbox" name="metric" value="1" <?php if ($metric=="1") echo "checked"?>> <b>Use metric units</b>
	 <br><p>
         <b>Language: </b><select name="language" size="1">
	      <option value="en" <?php if ($language=="en") echo "selected"?>>english</option>
	      <option value="de" <?php if ($language=="de") echo "selected"?>>deutsch</option>
	 </select><br><p>
	 <b>Forecast</b>
         <table border="1">
         <tr>
             <td>&nbsp;</td>
             <td>Day 1</td>
             <td>Day 2</td>
             <td>Day 3</td>
             <td>Day 4</td>
             <td>Day 5</td>
             <td>Day 6</td>
             <td>Day 7</td>
             <td>Day 8</td>
             <td>Day 9</td>
         </tr>
         <tr><td>Daytime</td>
             <td><input type="checkbox" name="day1" value="1" 
		   <?php if (substr($daytime,0,1)=="1") echo "checked"?>></td>
             <td><input type="checkbox" name="day2" value="1" 
		   <?php if (substr($daytime,1,1)=="1") echo "checked"?>></td> 
             <td><input type="checkbox" name="day3" value="1" 
		   <?php if (substr($daytime,2,1)=="1") echo "checked"?>></td> 
	     <td><input type="checkbox" name="day4" value="1" 
		   <?php if (substr($daytime,3,1)=="1") echo "checked"?>></td> 
             <td><input type="checkbox" name="day5" value="1" 
		   <?php if (substr($daytime,4,1)=="1") echo "checked"?>></td> 
             <td><input type="checkbox" name="day6" value="1" 
		   <?php if (substr($daytime,5,1)=="1") echo "checked"?>></td> 
             <td><input type="checkbox" name="day7" value="1" 
		   <?php if (substr($daytime,6,1)=="1") echo "checked"?>></td> 
             <td><input type="checkbox" name="day8" value="1" 
		   <?php if (substr($daytime,7,1)=="1") echo "checked"?>></td> 
             <td><input type="checkbox" name="day9" value="1" 
		   <?php if (substr($daytime,8,1)=="1") echo "checked"?>></td>
         </tr>
         <tr><td>Nighttime</td>
             <td><input type="checkbox" name="night1" value="1" 
		 <?php if (substr($nighttime,0,1)=="1") echo "checked"?>></td>
             <td><input type="checkbox" name="night2" value="1" 
		 <?php if (substr($nighttime,1,1)=="1") echo "checked"?>></td> 
             <td><input type="checkbox" name="night3" value="1" 
		 <?php if (substr($nighttime,2,1)=="1") echo "checked"?>></td> 
	     <td><input type="checkbox" name="night4" value="1" 
		 <?php if (substr($nighttime,3,1)=="1") echo "checked"?>></td> 
             <td><input type="checkbox" name="night5" value="1" 
		 <?php if (substr($nighttime,4,1)=="1") echo "checked"?>></td> 
             <td><input type="checkbox" name="night6" value="1" 
		 <?php if (substr($nighttime,5,1)=="1") echo "checked"?>></td> 
             <td><input type="checkbox" name="night7" value="1" 
		 <?php if (substr($nighttime,6,1)=="1") echo "checked"?>></td> 
             <td><input type="checkbox" name="night8" value="1" 
		 <?php if (substr($nighttime,7,1)=="1") echo "checked"?>></td> 
             <td><input type="checkbox" name="night9" value="1" 
		 <?php if (substr($nighttime,8,1)=="1") echo "checked"?>></td>
         </tr>
       </table>
     </fieldset>

<div class="submit">
  <input type="submit" name="info_update" value="<?php
    _e('Update options', 'Localization name')
	?> »" /></div>
<hr>
     <fieldset name="set2">
	 <legend><?php _e('Search location', 'Localization name') ?></legend><p>
<?php
   if (count($loc)<=0) { 	 
       echo "<b>Searchterm:</b>\n";
       echo "<input name=\"searchloc\" type=\"text\" size=\"30\" maxlength=\"30\"><br><p>\n";
       if (isset($_POST['search_loc'])) { 
	   echo "No locations found.<p>";
       }
       echo "</fieldset>\n";
       echo "<div class=\"submit\">\n";
       echo "<input type=\"submit\" name=\"search_loc\" value=\"" ;
       echo _e('Search location', 'Localization name');
       echo " »\" />\n";
   } else {
       echo "<b>Search result: </b><select name=\"newloc\" size=\"1\">\n";
       foreach ($loc as $l) {
	   echo "<option value=\"".$l['location']."\">";
	   echo $l['city']."/".$l['state'];
	   echo "</option>\n";
       }
       echo "</select><br>Please select your city and press set location.<p>\n";
       echo "</fieldset>\n";
        echo "<div class=\"submit\">\n";
	echo "<input type=\"submit\" name=\"set_loc\" value=\"" ;
       echo  _e('Set location', 'Localization name');
       echo " »\" />\n";
   } ?>
 
  </div></form>
 </div><?php
}
?>
